/*

    Timers.h  -  Header file for use with Timers.c

    Copyright (C) 2008  J. op den Brouw <jesse@opdenbrouw.nl>

    This file is part of Timers version 0.1

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/


#include <stdint.h>


#ifndef _TIMERS_H_
#define _TIMERS_H_

/* Define total number of timers */
#define NR_TIMERS 8

/* Timer tick type, should be one of uint16 or uint32 */
typedef uint16_t timer_tick_t;

/* Timer structure */
typedef struct timer_struct {
	uint8_t      inuse;		/* timer in use */
	uint8_t      active;    /* timer active (started or stopped */
	timer_tick_t ticks;     /* how many ticks so far */
	timer_tick_t maxticks;  /* turnover tick count */
	uint8_t      overflow;  /* did timer overflow? */
} timer_t;


/* Function prototypes */

/* Initialize timers */
void timer_initialize_timers(void);
/* Try to acquire a timer */
int8_t timer_acquire_timer(int8_t nr);
/* Try to release a timer */
int8_t timer_release_timer(int8_t nr);
/* Try to start a timer */
int8_t timer_start_timer(int8_t nr);
/* Try to stop a timer */
int8_t timer_stop_timer(int8_t nr);
/* Update timer ticks, ONLY TO BE CALLED FROM AN ISR */
void timer_update_timers(void);
/* Set maximum ticks (timer time) */
int8_t timer_set_maxticks(int8_t nr, timer_tick_t nr_ticks);
/* Get overflow status of timer */
int8_t timer_get_overflow(int8_t nr);

#endif
